#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shellmet
version:              0.0.6.0
visibility:           public
id:                   shellmet-0.0.6.0-JlDSovGzshtEgUGVFgnutT
key:                  shellmet-0.0.6.0-JlDSovGzshtEgUGVFgnutT
license:              MPL-2.0
copyright:            2019-2026 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/shellmet
synopsis:             Out of the shell solution for scripting in Haskell
description:
    Shellmet provides easy and convenient way to call shell commands from Haskell programs

category:             Shell, Command Line
abi:                  c8bc7aa5044b48dc5eb287b4c3c5f209
exposed:              True
exposed-modules:      Shellmet
import-dirs:          /usr/lib/ghc-9.6.6/site-local/shellmet-0.0.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/shellmet-0.0.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/shellmet-0.0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shellmet
hs-libraries:         HSshellmet-0.0.6.0-JlDSovGzshtEgUGVFgnutT
depends:              base-4.18.2.1 process-1.6.19.0 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-shellmet/html/shellmet.haddock
haddock-html:         /usr/share/doc/haskell-shellmet/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

